@@ -4,8 +4,6 @@
  */
 Ext.m3.GridPanel = Ext.extend(Ext.grid.GridPanel, {
 	constructor: function(baseConfig, params){
-//		console.log(baseConfig);
-//		console.log(params);
 		
 		// Добавлене selection model если нужно
 		var selModel = params.selModel;
@@ -18,7 +16,7 @@ Ext.m3.GridPanel = Ext.extend(Ext.grid.GridPanel, {
 		var funcContMenu;
 		if (params.menus.contextMenu && 
 			params.menus.contextMenu instanceof Ext.menu.Menu) {
-			
+
 			funcContMenu = function(e){
 				e.stopEvent();
 	            params.menus.contextMenu.showAt(e.getXY())
@@ -60,11 +58,17 @@ Ext.m3.GridPanel = Ext.extend(Ext.grid.GridPanel, {
 			,rowcontextmenu: funcRowContMenu
 			,beforerender: function(){
 				var bbar = this.getBottomToolbar();
-				if (bbar && bbar instanceof Ext.PagingToolbar){
+				var pageBar =
+					bbar && bbar.items && bbar.items.items &&
+					bbar.items.items.find(function(item) {
+						return item instanceof Ext.PagingToolbar;
+					}) ||
+					bbar;
+				if (pageBar && pageBar instanceof Ext.PagingToolbar) {
 					var store = this.getStore();
-					store.setBaseParam('start',0);
-					store.setBaseParam('limit',bbar.pageSize);
-					bbar.bind(store);
+					store.setBaseParam('start', 0);
+					store.setBaseParam('limit', pageBar.pageSize);
+					pageBar.bind(store);
 				}
 			}	
 		},
@@ -87,17 +91,12 @@ Ext.m3.GridPanel = Ext.extend(Ext.grid.GridPanel, {
 	 * Обработчик исключений хранилица
 	 */
 	storeException: function (proxy, type, action, options, response, arg){
-		//console.log(proxy, type, action, options, response, arg);
 		uiAjaxFailMessage(response, options);
 	}
 });
 
-Ext.reg('gridpanel', Ext.m3.GridPanel);
-
 Ext.m3.EditorGridPanel = Ext.extend(Ext.grid.EditorGridPanel, {
   constructor: function(baseConfig, params){
-//    console.log(baseConfig);
-//    console.log(params);
     
     // Добавлене selection model если нужно
     var selModel = params.selModel;
@@ -105,28 +104,31 @@ Ext.m3.EditorGridPanel = Ext.extend(Ext.grid.EditorGridPanel, {
     if (selModel && selModel instanceof Ext.grid.CheckboxSelectionModel) {
       gridColumns.columns.unshift(selModel);
     }
-    
-    // Навешивание обработчиков на контекстное меню если нужно 
+
+    // Навешивание обработчиков на контекстное меню если нужно
     var funcContMenu;
-    if (params.menus.contextMenu && 
+    if (params.menus.contextMenu &&
       params.menus.contextMenu instanceof Ext.menu.Menu) {
-      
+
       funcContMenu = function(e){
         e.stopEvent();
-              params.menus.contextMenu.showAt(e.getXY())
+		params.menus.contextMenu.showAt(e.getXY())
       }
     } else {
       funcContMenu = Ext.emptyFn;
     }
-    
+
     var funcRowContMenu;
-    if (params.menus.rowContextMenu && 
+    if (params.menus.rowContextMenu &&
       params.menus.contextMenu instanceof Ext.menu.Menu) {
-      
+
       funcRowContMenu = function(grid, index, e){
         e.stopEvent();
-                this.getSelectionModel().selectRow(index);
-                params.menus.rowContextMenu.showAt(e.getXY())
+        var selectionModel = this.getSelectionModel();
+		if (selectionModel instanceof Ext.grid.RowSelectionModel){
+        	selectionModel.selectRow(index);
+        	params.menus.rowContextMenu.showAt(e.getXY());
+		}
       }
     } else {
       funcRowContMenu = Ext.emptyFn;
@@ -178,7 +180,6 @@ Ext.m3.EditorGridPanel = Ext.extend(Ext.grid.EditorGridPanel, {
 	 * Обработчик исключений хранилица
 	 */
 	,storeException: function (proxy, type, action, options, response, arg){
-		//console.log(proxy, type, action, options, response, arg);
 		if (type == 'remote' && action != Ext.data.Api.actions.read) {
 		  if (response.raw.message) {
   		  Ext.Msg.show({
@@ -192,6 +193,4 @@ Ext.m3.EditorGridPanel = Ext.extend(Ext.grid.EditorGridPanel, {
 		  uiAjaxFailMessage(response, options);
 		}
 	}
-});
-
-Ext.reg('editorgridpanel', Ext.m3.EditorGridPanel);
+});
\ No newline at end of file
