@@ -514,20 +514,16 @@ var restoreClass = function (readOnly) {
 
 Ext.override(Ext.form.Field, {
     setReadOnly: function (readOnly) {
-        if(readOnly || !(this.ownerCt && this.ownerCt.readOnly)){
-            setReadOnlyField.call(this, readOnly);
-            restoreClass.call(this, readOnly);
-        }
+        setReadOnlyField.call(this, readOnly);
+        restoreClass.call(this, readOnly);
     }
 });
 
 var setReadOnlyTriggerField = Ext.form.TriggerField.prototype.setReadOnly;
 Ext.override(Ext.form.TriggerField, {
     setReadOnly: function (readOnly) {
-        if(readOnly || !(this.ownerCt && this.ownerCt.readOnly)){
-            setReadOnlyTriggerField.call(this, readOnly);
-            restoreClass.call(this, readOnly);
-        }
+        setReadOnlyTriggerField.call(this, readOnly);
+        restoreClass.call(this, readOnly);
     }
 });
 
@@ -537,8 +533,54 @@ Ext.override(Ext.form.TriggerField, {
  *     colModel.setColumnWidth(i, Math.max(grid.minColumnWidth, Math.floor(colWidth + colWidth * fraction)), true);
  * стало:
  *     colModel.setColumnWidth(i, Math.floor(colWidth + colWidth * fraction), true);
+
+ *  Добавлено проставление стилей заголовкам колонок грида
  */
 Ext.override(Ext.grid.GridView, {
+    renderHeaders : function() {
+        var colModel   = this.cm,
+            templates  = this.templates,
+            headerTpl  = templates.hcell,
+            properties = {},
+            colCount   = colModel.getColumnCount(),
+            last       = colCount - 1,
+            cells      = [],
+            i, cssCls;
+
+        for (i = 0; i < colCount; i++) {
+            if (i == 0) {
+                cssCls = 'x-grid3-cell-first ';
+            } else {
+                cssCls = i == last ? 'x-grid3-cell-last ' : '';
+            }
+
+            if(colModel.columns[i].cls) {
+                cssCls = cssCls + colModel.columns[i].cls;
+            }
+
+            properties = {
+                id     : colModel.getColumnId(i),
+                value  : colModel.getColumnHeader(i) || '',
+                style  : this.getColumnStyle(i, true),
+                css    : cssCls,
+                tooltip: this.getColumnTooltip(i)
+            };
+
+            if (colModel.config[i].align == 'right') {
+                properties.istyle = 'padding-right: 16px;';
+            } else {
+                delete properties.istyle;
+            }
+
+            cells[i] = headerTpl.apply(properties);
+        }
+
+        return templates.header.apply({
+            cells : cells.join(""),
+            tstyle: String.format("width: {0};", this.getTotalWidth())
+        });
+    },
+
     fitColumns: function (preventRefresh, onlyExpand, omitColumn) {
         var grid = this.grid,
             colModel = this.cm,
@@ -630,188 +672,48 @@ Ext.override(Ext.Element, {
 });
 
 /**
- * BOBUH-19922 Добавлен вызов ивента beforeaddmenuitem перед добавлением элементов в контекстное меню колонки
- * Было:
- *     menu.add(new Ext.menu.CheckItem({
- *                         itemId: "col-" + cm.getColumnId(col),
- *                         text: text.join(' '),
- *                         checked: !cm.isHidden(col),
- *                         hideOnClick: false,
- *                         disabled: cm.config[col].hideable === false
- *                     }));
- * Стало:
- *     var newMenuItem = new Ext.menu.CheckItem({
- *                         itemId: "col-" + cm.getColumnId(col),
- *                         text: text.join(' '),
- *                         checked: !cm.isHidden(col),
- *                         hideOnClick: false,
- *                         disabled: cm.config[col].hideable === false
- *                     });
- *                     cm.fireEvent('beforeaddmenuitem', cm, newMenuItem);
- *                     menu.add(newMenuItem);
- */
-function beforeColMenuShow(){
-    var cm = this.cm,
-        rows = this.cm.rows,
-        menu,
-        text,
-        group,
-        gcol,
-        r,
-        title;
-    this.colMenu.removeAll();
-
-    for(var col = 0, clen = cm.getColumnCount(); col < clen; col++){
-        menu = this.colMenu;
-        title = cm.getColumnHeader(col);
-        text = [];
-
-        if(cm.config[col].fixed !== true && cm.config[col].hideable !== false){
-
-            for(var row = 0, rlen = rows.length; row < rlen; row++){
-                r = rows[row];
-                gcol = 0;
-
-                for(var i = 0, len = r.length; i < len; i++){
-                    group = r[i];
-
-                    if(col >= gcol && col < gcol + group.colspan){
-                        break;
-                    }
-                    gcol += group.colspan;
-                }
-
-                if(group && group.header){
-
-                    if(cm.hierarchicalColMenu){
-                        var gid = 'group-' + row + '-' + gcol,
-                            item = menu.items ? menu.getComponent(gid) : null,
-                            submenu = item ? item.menu : null;
-
-                        if(!submenu){
-                            submenu = new Ext.menu.Menu({
-                                itemId: gid
-                            });
-                            submenu.on("itemclick", this.handleHdMenuClick, this);
-                            var checked = false,
-                                disabled = true;
-
-                            for(var c = gcol, lc = gcol + group.colspan; c < lc; c++){
-
-                                if(!cm.isHidden(c)){
-                                    checked = true;
-                                }
-
-                                if(cm.config[c].hideable !== false){
-                                    disabled = false;
-                                }
-                            }
-                            menu.add({
-                                itemId: gid,
-                                text: group.header,
-                                menu: submenu,
-                                hideOnClick: false,
-                                checked: checked,
-                                disabled: disabled
-                            });
-                        }
-                        menu = submenu;
-                    }
-
-                    else{
-                        text.push(group.header);
-                    }
+* Предотвращает баг при котором показывается множество тултипов из-за
+* задержки показывания при проведении мышкой по нескольким элементам по очереди
+* например в гриде
+*/
+Ext.ToolTip.override({
+    onMouseMove : function(e){
+        var t = this.delegate ? e.getTarget(this.delegate) : this.triggerElement = true;
+        if (t) {
+            this.targetXY = e.getXY();
+            if (t === this.triggerElement) {
+                if(!this.hidden && this.trackMouse){
+                    this.setPagePosition(this.getTargetXY());
                 }
+            } else {
+                this.hide();
+                this.lastActive = new Date(0);
+                this.onTargetOver(e);
             }
-            text.push(title);
-            var newMenuItem = new Ext.menu.CheckItem({
-                itemId: "col-" + cm.getColumnId(col),
-                text: text.join(' '),
-                checked: !cm.isHidden(col),
-                hideOnClick: false,
-                disabled: cm.config[col].hideable === false
-            });
-            cm.fireEvent('beforeaddmenuitem', cm, newMenuItem);
-            menu.add(newMenuItem);
+        } else if (!this.closable) {
+            this.clearTimer('show');
+            this.hide();
         }
     }
-};
-
-Ext.override(Ext.ux.grid.ColumnHeaderGroup, {
-    init: function(grid){
-        this.viewConfig.beforeColMenuShow = beforeColMenuShow;
-        Ext.applyIf(grid.colModel, this.config);
-        Ext.apply(grid.getView(),this.viewConfig);
-    }
 });
 
-
 /**
- * Очень пытливые умы успевают за короткое время несколько раз кликнуть на кнопку. Не спасает даже disabled, потому что
- * он не успеват сработать. Это в определенных случаях приводит к неприятным последствиям. Например, один документ
- * может сохраниться дважды и в этом случае мы получаем копии, которые нам не нужны.
- * Поэтому делаем финт ушами и запоминаем момент последнего клика на кнопке и в течение ближайших 500 миллисекунд не
- * дадим повторно выполнить это же действие.
+* Унифицирует поведение в современных браузерах.
+* В старых версиях firefox на платформах отличных от Windows, была нужна
+* обработка события keypress. Сейчас нормально работает keydown.
+*/
+Ext.apply(Ext.EventManager, {
+        useKeydown: Ext.isWebKit ?
+            Ext.num(navigator.userAgent.match(/AppleWebKit\/(\d+)/)[1]) >= 525 :
+            !Ext.isOpera
+});
+
+/**
+ * Добавление возможности указать флаг exactMatch для поиска точного совпадения.
  */
-Ext.override(Ext.Button, {
-    onClick: function(e) {
-        var me = this,
-            now = Date.now();
-
-        if (now < me.lastClickTimestamp + 500) {
-            me.lastClickTimestamp = now;
-            return;
-        }
-        me.lastClickTimestamp = now;
-
-        if (e) {
-            e.preventDefault();
-        }
-        if (e.button !== 0) {
-            return;
-        }
-        if (!this.disabled) {
-            this.doToggle();
-            if (this.menu && !this.hasVisibleMenu() && !this.ignoreNextClick) {
-                this.showMenu();
-            }
-            this.fireEvent('click', this, e);
-            if (this.handler) {
-
-                this.handler.call(this.scope || this, this, e);
-            }
-        }
+Ext.data.Store.override({
+    find: function(property, value, start, anyMatch, caseSensitive, exactMatch) {
+        var fn = this.createFilterFn(property, value, anyMatch, caseSensitive, exactMatch);
+        return fn ? this.data.findIndexBy(fn, null, start) : -1;
     }
-});
-
-
-Ext.override(Ext.m3.AdvancedDataField, {
-    onBlur : function(){
-	/*
-	   В суперклассе Ext.form.TriggerField данный метод перекрывается пустой функцией,
-   	   видимо для того, чтобы все изменения и событие change происходили только при нажатии на триггеры,
- 	   но данное поведение весьма неудобно в колоночных фильтрах, где требуется корректное срабатывание
-       blur и change при потере фокуса. Также есть проверка для прерывания дальнейших неправильных вызовов.
-	   Данная реализация метода взята из базового класса Ext.formField
-	*/
-        if (this.value == this.getRawValue()) {
-            return;
-        }
-
-	    this.beforeBlur();
-	    if(this.focusClass){
-	        this.el.removeClass(this.focusClass);
-	    }
-	    this.hasFocus = false;
-	    if(this.validationEvent !== false && (this.validateOnBlur || this.validationEvent == 'blur')){
-	        this.validate();
-	    }
-	    var v = this.getValue();
-	    if(String(v) !== String(this.startValue)){
-	        this.fireEvent('change', this, v, this.startValue);
-	    }
-	    this.fireEvent('blur', this);
-	    this.postBlur();
-    }
-
-});
+});
\ No newline at end of file
