@@ -226,7 +226,7 @@ class BaseExtComponent(object):
         elif isinstance(item, bool):
             res = str(item).lower()
 
-        elif isinstance(item, (six.integer_types, float, decimal.Decimal)):
+        elif isinstance(item, (int, float, decimal.Decimal, int)):
             res = item
 
         elif isinstance(item, datetime.date):
@@ -452,9 +452,6 @@ class ExtUIComponent(BaseExtComponent):
         # CSS стиль для label
         self.label_style = {}
 
-        # Разделитель для label
-        self.label_separator = None
-        
     def t_render_style(self):
         """
         :deprecated: Использовать рендеринг в render_base_config
@@ -494,7 +491,6 @@ class ExtUIComponent(BaseExtComponent):
         if self.label_style:
             self._put_config_value('labelStyle', self.t_render_label_style())
         self._put_config_value('hideLabel', self.hide_label, self.hide_label)
-        self._put_config_value('labelSeparator', self.label_separator, self.label_separator is not None)
 
     def make_read_only(
             self, access_off=True, exclude_list=(), *args, **kwargs):
