@@ -5,6 +5,7 @@ from datetime import date
 from datetime import datetime
 
 from django.conf import settings
+from django.utils.html import escapejs
 from m3 import date2str
 
 from .base import BaseExtField
@@ -56,10 +57,7 @@ class ExtStringField(BaseExtField):
         # Кавычки, апострафы, символы переноса строки и т.д. отрежутся функцией normalize в helpers/__init__.py
         # TODO нужно разобраться почему иногда по-умолчанию приходит None, вместо пустой строки.
         if self.value:
-            if not isinstance(self.value, six.string_types):
-                raise RuntimeError(
-                    'Field "{0}" should have string value, but gets {1} "{2}"'
-                    ''.format(self.name, type(self.value), repr(self.value)))
+            self.value = self.value.replace('\\', '\\\\')
 
         super(ExtStringField, self).render_base_config()
         self._put_config_value('inputType', self.input_type)
@@ -157,6 +155,33 @@ class ExtDateField(BaseExtField):
         return 'createAdvancedDataField({%s},{%s})' % (base_config, params)
 
 
+class ExtMultipleDateField(ExtDateField):
+    """Поле ввода даты с множественным выбором."""
+
+    def __init__(self, *args, **kwargs):
+        super(ExtMultipleDateField, self).__init__(*args, **kwargs)
+
+        self.editable = False
+        self.delimiter = ','
+        self.init_component(*args, **kwargs)
+
+    def render_params(self):
+        """Проброс `delimiter` в javascript компонент."""
+        super(ExtMultipleDateField, self).render_params()
+        self._put_params_value('delimiter', self.delimiter)
+
+    def render(self):
+        try:
+            self.render_base_config()
+            self.render_params()
+        except UnicodeDecodeError as msg:
+            raise Exception(msg)
+
+        base_config = self._get_config_str()
+        params = self._get_params_str()
+        return 'createMultipleDateField({%s},{%s})' % (base_config, params)
+
+
 class ExtNumberField(BaseExtField):
     """
     Поле ввода числового значения
@@ -173,9 +198,6 @@ class ExtNumberField(BaseExtField):
         # Разделитель целой и дробной части
         self.decimal_separator = None
 
-        # Включение разбиения числа на тысячные разряды
-        self.use_thousand_separator = True
-
         # Разделитель тысячных частей
         self.thousand_separator = None
 
@@ -213,8 +235,6 @@ class ExtNumberField(BaseExtField):
     def render_base_config(self):
         super(ExtNumberField, self).render_base_config()
         self._put_config_value('decimalSeparator', self.decimal_separator)
-        self._put_config_value(
-            'useThousandSeparator', self.use_thousand_separator)
         self._put_config_value('thousandSeparator', self.thousand_separator)
         self._put_config_value('allowDecimals', self.allow_decimals)
         self._put_config_value('allowNegative', self.allow_negative)
@@ -277,6 +297,8 @@ class ExtTextArea(BaseExtField):
         return '/%s/' % self.mask_re
 
     def render_base_config(self):
+        if self.value:
+            self.value = escapejs(self.value)
         super(ExtTextArea, self).render_base_config()
         self._put_config_value('maskRe', self.t_render_mask_re, self.mask_re)
 
@@ -298,6 +320,9 @@ class ExtCheckBox(BaseExtField):
     def __init__(self, *args, **kwargs):
         super(ExtCheckBox, self).__init__(*args, **kwargs)
 
+        #TODO: Необходимо отрефакторить под внутриклассовый рендеринг
+        self.template = 'ext-fields/ext-checkbox.js'
+
         # Признак того, что значение выбрано
         self.checked = False
 
@@ -306,18 +331,6 @@ class ExtCheckBox(BaseExtField):
 
         self.init_component(*args, **kwargs)
 
-    def render_base_config(self):
-        super(ExtCheckBox, self).render_base_config()
-
-        self._put_config_value('checked', self.checked, self.checked)
-        self._put_config_value('boxLabel', self.box_label, self.box_label)
-
-    def render(self):
-        self.render_base_config()
-
-        base_config = self._get_config_str()
-        return 'new Ext.form.Checkbox({%s})' % base_config
-
     @property
     def handler_check(self):
         return self._listeners.get('check')
@@ -432,6 +445,7 @@ class ExtHTMLEditor(BaseExtField):
             if not isinstance(self.value, six.string_types):
                 # Если value не строка, то пытаемся привести к unicode
                 self.value = six.text_type(self.value)
+            self.value = self.value.replace('\\', '\\\\')
         super(ExtHTMLEditor, self).render_base_config()
 
     def render(self):
